#
# spec file for package perl-File-Temp
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-File-Temp
Version:        0.2304
Release:        lp152.3.2
%define         cpan_name File-Temp
Summary:        Return name and handle of a temporary file safely
License:        Artistic-1.0 or GPL-1.0+
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/File-Temp/
Source:         http://www.cpan.org/authors/id/D/DA/DAGOLDEN/%{cpan_name}-%{version}.tar.gz
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(File::Path) >= 2.06
BuildRequires:  perl(parent) >= 0.221
Requires:       perl(File::Path) >= 2.06
Requires:       perl(parent) >= 0.221
%{perl_requires}

%description
'File::Temp' can be used to create and open temporary files in a safe way.
There is both a function interface and an object-oriented interface. The
File::Temp constructor or the tempfile() function can be used to return the
name and the open filehandle of a temporary file. The tempdir() function
can be used to create a temporary directory.

The security aspect of temporary file creation is emphasized such that a
filehandle and filename are returned together. This helps guarantee that a
race condition can not occur where the temporary file is created by another
process between checking for the existence of the file and its opening.
Additional security levels are provided to check, for example, that the
sticky bit is set on world writable directories. See the "safe_level"
manpage for more information.

For compatibility with popular C library functions, Perl implementations of
the mkstemp() family of functions are provided. These are, mkstemp(),
mkstemps(), mkdtemp() and mktemp().

Additionally, implementations of the standard POSIX tmpnam() and tmpfile()
functions are provided if required.

Implementations of mktemp(), tmpnam(), and tempnam() are provided, but
should be used with caution since they return only a filename that was
valid when function was called, so cannot guarantee that the file will not
exist by the time the caller opens the filename.

Filehandles returned by these functions support the seekable methods.

%prep
%setup -q -n %{cpan_name}-%{version}
# MANUAL BEGIN
%if 0%{?suse_version} <= 1110
for i in `find t -type f` ; do
    sed -i -e "s@^\s*use\s\s*Test::More@use lib '%{perl_vendorlib}';\nuse Test::More@" $i
done
sed -i -e "s|package File::Temp;|package File::Temp;\nuse lib '%{perl_vendorlib}';|" lib/File/Temp.pm 
%endif
# MANUAL END

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes CONTRIBUTING cpanfile LICENSE README

%changelog
* Fri Jan 17 2014 lars@linux-schulserver.de
- update to 0.2304:
  * List all detectable dependencies for completeness. (Test::More had
    been unintentionally omitted in the last release and many core
    dependencies had never been listed.)
  * Remove compile test and associated dependencies
- Fix summary
- fix build on SLE_11 (use vendorlib for Test::More and File::Path)
* Fri Oct  4 2013 coolo@suse.com
- updated to 0.2302
  * Drop minimum Perl version back to 5.6 (erroneously bumped by dzil)
  * Do not inherit from Exporter (requires Exporter 5.57) (thanks to
    Olivier Mengué)
  * 'use base ...' => 'use parent ...' as parent is lighter (thanks to
    Olivier Mengué)
  * dist.ini: Managed with Dist::Zilla now; generates Makefile.PL
    to avoid circular dependency when using Build.PL
  * Build.PL: Use Module::Build
  * Temp.pm: internally holds absolute path for cleanup (Fixes RT #44924)
  * t/rmtree.t: (new) Test temp dir removal explicitly.
  * t/tempfile.t: Correctly tests directory removal from chdir.
  * Temp.pm: Clean up temp directory on exit even if it is the
    current directory. Patch supplied by Ed Avis and fixes RT #45246.
  * Temp.pm: Defer unlinking tempfiles if initial unlink fails
    instad of croaking; fixes problems on NFS (RT #82720)
  * Temp.pm: Allow leading template to new() for consistency with
    newdir()
  * Temp.pm: Calling tempfile or tempdir as a class method now
    produce a more useful fatal error message
  * Temp.pm: new/newdir/tempfile/tempdir now all allow either
    a leading template argument or a TEMPLATE option
  * Temp.pm: Overload numify with refaddr() in same manner as IO::File
    (closes RT #47397 from Kevin Ryde)
* Fri Nov 18 2011 coolo@suse.com
- use original tar.gz
* Sun Jun  5 2011 lars@linux-schulserver.de
- update to 0.22
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Sat Jul 25 2009 chris@computersalat.de
- spec mods
  * removed ^----------
  * removed ^#---------
* Sun Jun 21 2009 chris@computersalat.de
- update to 0.21
- added perl-macros
  o autogen filelist with perl_gen_filelist
* Wed Aug 20 2008 rpm@scorpio-it.net - 0.20
- initial Package
